import { LoggingPlugin } from './loggingPlugin';
import { LogLevel } from './logLevel';
import { LogMessage, LogMessageMeta, LogMessageObject } from './logMessage';
/**
 * A LoggingServiceConfig interface that contains the configuration for the LoggingService.
 */
export interface LoggingServiceConfig {
    /**
     * Object to be included with each log from the logger.
     *
     * @example
     * Here's an example of how to include the service name in each log message:
     * ```
     * {
     *    metadata: {
     *      service: "example-service"
     *    }
     * }
     * ```
     */
    defaultMetadata?: LogMessageObject;
    /**
     * The maximum log level to log.
     */
    maxLogLevel?: LogLevel;
    /**
     * The plugin used to send the logs. Must implement the {@link LoggingPlugin} interface
     */
    loggingPlugin?: LoggingPlugin;
    /**
     * If true, will include the function name, file name, and line number of the calling function.
     * format: \<function name\> (\<file name\>:\<line number\>)
     *
     * Note: Only compatible with the V8 JavaScript engine (Node.js, Chromium-based web browsers, etc.)
     */
    includeLocation?: boolean;
}
/**
 * A LoggingService instance.
 */
export declare class LoggingService {
    private _loggingPlugin;
    private _includeLocation;
    /**
     *
     * @param config - The {@link LoggingServiceConfig} object
     *
     *  * default values:
     * ```
     * {
     *    logLevel: "info", // Will log error, warn, and info log levels
     *    transports: [ new ConsoleTransport() ],
     *    includeLocation: true
     * }
     * ```
     */
    constructor(config?: LoggingServiceConfig);
    /**
     * Logs using the "error" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    error(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "error" log level
     *
     * @param message - The message to be logged
     */
    error(message: LogMessage): void;
    /**
     * Logs using the "warn" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    warn(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "warn" log level
     *
     * @param message - The message to be logged
     */
    warn(message: LogMessage): void;
    /**
     * Logs using the "info" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    info(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "info" log level
     *
     * @param message - The message to be logged
     */
    info(message: LogMessage): void;
    /**
     * Logs using the "http" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    http(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "http" log level
     *
     * @param message - The message to be logged
     */
    http(message: LogMessage): void;
    /**
     * Logs using the "verbose" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    verbose(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "verbose" log level
     *
     * @param message - The message to be logged
     */
    verbose(message: LogMessage): void;
    /**
     * Logs using the "debug" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    debug(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "debug" log level
     *
     * @param message - The message to be logged
     */
    debug(message: LogMessage): void;
    /**
     * Logs using the "silly" log level
     *
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    silly(message: string, meta: LogMessageMeta): void;
    /**
     * Logs using the "silly" log level
     *
     * @param message - The message to be logged
     */
    silly(message: LogMessage): void;
    /**
     * Takes a log message, optionally appends the calling function location and metadata, and sends to the Winston logger
     *
     * @param level - The {@link LogLevel} to log at
     * @param message - The message to be logged
     * @param meta - Any additional data to be included in the log
     */
    private _log;
    /**
     * Creates a string representation of the log method's calling function
     *
     * @returns a string in the format: \<function name\> (\<file name\>:\<line number\>)
     */
    private _getCallingFunctionLocation;
}
//# sourceMappingURL=loggingService.d.ts.map