"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggingService = void 0;
const winstonPlugin_1 = require("./plugins/winstonPlugin");
/**
 * A LoggingService instance.
 */
class LoggingService {
    /**
     *
     * @param config - The {@link LoggingServiceConfig} object
     *
     *  * default values:
     * ```
     * {
     *    logLevel: "info", // Will log error, warn, and info log levels
     *    transports: [ new ConsoleTransport() ],
     *    includeLocation: true
     * }
     * ```
     */
    constructor(config = {
        maxLogLevel: 'info',
        loggingPlugin: new winstonPlugin_1.WinstonPlugin(),
        includeLocation: true
    }) {
        var _a, _b, _c;
        this._includeLocation = (_a = config.includeLocation) !== null && _a !== void 0 ? _a : true;
        this._loggingPlugin = (_b = config.loggingPlugin) !== null && _b !== void 0 ? _b : new winstonPlugin_1.WinstonPlugin();
        this._loggingPlugin.setMaxLogLevel((_c = config.maxLogLevel) !== null && _c !== void 0 ? _c : 'info');
        if (config.defaultMetadata) {
            this._loggingPlugin.setDefaultMetadata(config.defaultMetadata);
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    error(message, meta) {
        this._log('error', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    warn(message, meta) {
        this._log('warn', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    info(message, meta) {
        this._log('info', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    http(message, meta) {
        this._log('http', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    verbose(message, meta) {
        this._log('verbose', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    debug(message, meta) {
        this._log('debug', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    silly(message, meta) {
        this._log('silly', message, meta);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    _log(level, message, meta) {
        if (meta) {
            if (this._includeLocation) {
                meta.location = this._getCallingFunctionLocation();
            }
            this._loggingPlugin.log(level, message, meta);
        }
        else {
            if (this._includeLocation) {
                this._loggingPlugin.log(level, message, { location: this._getCallingFunctionLocation() });
            }
            else {
                this._loggingPlugin.log(level, message);
            }
        }
    }
    /**
     * Creates a string representation of the log method's calling function
     *
     * @returns a string in the format: \<function name\> (\<file name\>:\<line number\>)
     */
    _getCallingFunctionLocation() {
        var _a;
        const temp = new Error();
        const lines = (_a = temp.stack) === null || _a === void 0 ? void 0 : _a.split(' at ')[4].trim();
        return `${lines}`;
    }
}
exports.LoggingService = LoggingService;
//# sourceMappingURL=loggingService.js.map